:hide-toc:

.. digital_tekstanalyse documentation master file, created by
    sphinx-quickstart on Thu Dec 30 16:43:55 2021.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.


================================================
dhlab documentation
================================================


..
    # Include the text from the README.md file

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- start dhlab-intro -->
   :end-before: <!-- end dhlab-intro -->


..
    # TODO: Add a demo view?


*******


Contents
--------------


..
    # The following toctree blocks are shown in the left side panel

.. toctree::
   :maxdepth: 2

   docs_getting_started.rst
   docs_notebooks.rst
   usage_api.rst
   usage_images.rst
   usage_metadata.rst
   usage_ngrams.rst
   usage_text.rst
   usage_utilities.rst
   package_summary.rst
   docs_changelog.rst

.. toctree::
   :hidden:
   :name: extlinks-toc
   :caption: External links

   Pypi package <https://pypi.org/project/dhlab/>
   Source code, GitHub <https://github.com/NationalLibraryOfNorway/DHLAB>
   Source Jupyter Notebooks, GitHub <https://github.com/NationalLibraryOfNorway/digital_tekstanalyse>
   Hosted Jupyter notebooks <https://mybinder.org/v2/gh/DH-LAB-NB/DHLAB/master>
   DH-lab Homepage <https://www.nb.no/dh-lab/>
   DH-lab Web applications <https://www.nb.no/dh-lab/apper/>
   Search the National Library online <https://www.nb.no/search>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
